/*
 * This file is loading the irep
 * Ruby GEM code.
 *
 * This file was generated by mruby/lib/mruby/gem.rb.
 *
 * IMPORTANT:
 *   This file was generated!
 *   All manual changes will get lost.
 */
#include <stdlib.h>
#include <mruby.h>
#include <mruby/irep.h>
#include <mruby/debug.h>
#include <mruby/proc.h>
#include <mruby/presym.h>

#define mrb_BRACED(...) {__VA_ARGS__}
#define mrb_DEFINE_SYMS_VAR(name, len, syms, qualifier) \
  static qualifier mrb_sym name[len] = mrb_BRACED syms

static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_2[1] = {
{IREP_TT_STR|(24<<2), {"\x76\x61\x6c\x75\x65\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x65\x6e\x75\x6d\x65\x72\x61\x62\x6c\x65"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_2, 4, (MRB_SYM(each), MRB_SYM_Q(respond_to), MRB_SYM(ArgumentError), MRB_SYM(raise), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_2[43] = {
0x34,0x04,0x00,0x01,0x01,0x03,0x01,0x10,0x04,0x00,0x2f,0x03,0x01,0x01,0x27,0x03,0x00,0x0d,0x01,0x03,
0x01,0x01,0x04,0x02,0x30,0x03,0x00,0x00,0x25,0x00,0x0a,0x1d,0x04,0x02,0x51,0x05,0x00,0x2d,0x03,0x03,
0x02,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_2, 2, (MRB_SYM(enum), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_2 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_2,
  gem_mrblib_mruby_set_proc_pool_2,gem_mrblib_mruby_set_proc_syms_2,NULL,
  gem_mrblib_mruby_set_proc_lv_2,
  NULL,					/* debug_info */
  43,1,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_3, 1, (MRB_IVSYM(hash), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_3[9] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_3, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_3 = {
  2,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_3,
  NULL,gem_mrblib_mruby_set_proc_syms_3,NULL,
  gem_mrblib_mruby_set_proc_lv_3,
  NULL,					/* debug_info */
  9,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_4, 1, (MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_4[13] = {
0x34,0x00,0x10,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_4, 2, (MRB_SYM(ary), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_4 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_4,
  NULL,gem_mrblib_mruby_set_proc_syms_4,NULL,
  gem_mrblib_mruby_set_proc_lv_4,
  NULL,					/* debug_info */
  13,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_182, 2, (MRB_SYM(call), MRB_SYM(add), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_182[21] = {
0x34,0x04,0x00,0x00,0x21,0x04,0x02,0x00,0x01,0x05,0x01,0x2f,0x04,0x00,0x01,0x2d,0x03,0x01,0x01,0x38,
0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_182, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_182 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_182,
  NULL,gem_mrblib_mruby_set_proc_syms_182,NULL,
  gem_mrblib_mruby_set_proc_lv_182,
  NULL,					/* debug_info */
  21,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_5[1] = {
  &gem_mrblib_mruby_set_proc_irep_182,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_5, 7, (MRB_IVSYM(hash), MRB_SYM(Hash), MRB_SYM(new), MRB_SYM_Q(nil), MRB_SYM_Q(block_given), MRB_SYM(__do_with_enum), MRB_SYM(merge), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_5[74] = {
0x34,0x00,0x20,0x01,0x25,0x00,0x03,0x25,0x00,0x02,0x11,0x01,0x19,0x03,0x00,0x26,0x03,0x00,0x0a,0x1d,
0x03,0x01,0x2f,0x03,0x02,0x00,0x1a,0x03,0x00,0x01,0x03,0x01,0x2f,0x03,0x03,0x00,0x27,0x03,0x00,0x04,
0x11,0x03,0x38,0x03,0x2d,0x03,0x04,0x00,0x27,0x03,0x00,0x0d,0x01,0x04,0x01,0x57,0x05,0x00,0x2e,0x03,
0x05,0x01,0x25,0x00,0x07,0x01,0x04,0x01,0x2d,0x03,0x06,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_5, 2, (MRB_SYM(enum), MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_5 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_5,
  NULL,gem_mrblib_mruby_set_proc_syms_5,gem_mrblib_mruby_set_proc_reps_5,
  gem_mrblib_mruby_set_proc_lv_5,
  NULL,					/* debug_info */
  74,0,7,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_6, 3, (MRB_SYM(__get_hash), MRB_SYM(dup), MRB_IVSYM(hash), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_6[27] = {
0x34,0x04,0x00,0x00,0x33,0x04,0x08,0x00,0x32,0x03,0x0f,0x01,0x03,0x01,0x2f,0x03,0x00,0x00,0x2f,0x03,
0x01,0x00,0x1a,0x03,0x02,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_6, 2, (MRB_SYM(orig), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_6 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_6,
  NULL,gem_mrblib_mruby_set_proc_syms_6,NULL,
  gem_mrblib_mruby_set_proc_lv_6,
  NULL,					/* debug_info */
  27,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_7, 2, (MRB_IVSYM(hash), MRB_SYM(size), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_7[13] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x2f,0x02,0x01,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_7, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_7 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_7,
  NULL,gem_mrblib_mruby_set_proc_syms_7,NULL,
  gem_mrblib_mruby_set_proc_lv_7,
  NULL,					/* debug_info */
  13,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_8, 2, (MRB_IVSYM(hash), MRB_SYM_Q(empty), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_8[13] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x2f,0x02,0x01,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_8, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_8 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_8,
  NULL,gem_mrblib_mruby_set_proc_syms_8,NULL,
  gem_mrblib_mruby_set_proc_lv_8,
  NULL,					/* debug_info */
  13,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_9, 2, (MRB_IVSYM(hash), MRB_SYM(clear), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_9[15] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x2f,0x02,0x01,0x00,0x12,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_9, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_9 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_9,
  NULL,gem_mrblib_mruby_set_proc_syms_9,NULL,
  gem_mrblib_mruby_set_proc_lv_9,
  NULL,					/* debug_info */
  15,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_10, 2, (MRB_SYM(clear), MRB_SYM(merge), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_10[17] = {
0x34,0x04,0x00,0x00,0x2d,0x03,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_10, 2, (MRB_SYM(enum), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_10 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_10,
  NULL,gem_mrblib_mruby_set_proc_syms_10,NULL,
  gem_mrblib_mruby_set_proc_lv_10,
  NULL,					/* debug_info */
  17,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_11, 2, (MRB_IVSYM(hash), MRB_SYM(keys), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_11[13] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x2f,0x02,0x01,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_11, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_11 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_11,
  NULL,gem_mrblib_mruby_set_proc_syms_11,NULL,
  gem_mrblib_mruby_set_proc_lv_11,
  NULL,					/* debug_info */
  13,0,2,0,0
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_498[1] = {
{IREP_TT_STR|(30<<2), {"\x74\x72\x69\x65\x64\x20\x74\x6f\x20\x66\x6c\x61\x74\x74\x65\x6e\x20\x72\x65\x63\x75\x72\x73\x69\x76\x65\x20\x53\x65\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_498, 8, (MRB_SYM(Set), MRB_SYM_Q(is_a), MRB_SYM(object_id), MRB_SYM_Q(include), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(flatten_merge), MRB_SYM(add), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_498[73] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x1d,0x05,0x00,0x2f,0x04,0x01,0x01,0x27,0x04,0x00,0x2e,0x21,0x04,
0x02,0x00,0x01,0x05,0x01,0x2f,0x05,0x02,0x00,0x01,0x03,0x05,0x2f,0x04,0x03,0x01,0x27,0x04,0x00,0x0a,
0x1d,0x05,0x04,0x51,0x06,0x00,0x2d,0x04,0x05,0x02,0x01,0x05,0x01,0x21,0x06,0x02,0x00,0x2d,0x04,0x06,
0x02,0x25,0x00,0x07,0x01,0x05,0x01,0x2d,0x04,0x07,0x01,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_498, 3, (MRB_SYM(e), 0,MRB_SYM(e_id), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_498 = {
  4,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_498,
  gem_mrblib_mruby_set_proc_pool_498,gem_mrblib_mruby_set_proc_syms_498,NULL,
  gem_mrblib_mruby_set_proc_lv_498,
  NULL,					/* debug_info */
  73,1,8,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_12[1] = {
  &gem_mrblib_mruby_set_proc_irep_498,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_12, 6, (MRB_SYM(Set), MRB_SYM(new), MRB_SYM(object_id), MRB_SYM(add), MRB_SYM(each), MRB_SYM(delete), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_12[62] = {
0x34,0x04,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x0a,0x1d,0x04,0x00,0x2f,0x04,0x01,0x00,0x01,0x02,0x04,
0x01,0x04,0x02,0x01,0x05,0x01,0x2f,0x05,0x02,0x00,0x2f,0x04,0x03,0x01,0x01,0x04,0x01,0x57,0x05,0x00,
0x30,0x04,0x04,0x00,0x01,0x04,0x02,0x01,0x05,0x01,0x2f,0x05,0x02,0x00,0x2f,0x04,0x05,0x01,0x12,0x04,
0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_12, 3, (MRB_SYM(set), MRB_SYM(seen), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_12 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_12,
  NULL,gem_mrblib_mruby_set_proc_syms_12,gem_mrblib_mruby_set_proc_reps_12,
  gem_mrblib_mruby_set_proc_lv_12,
  NULL,					/* debug_info */
  62,0,6,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_13, 3, (MRB_SYM(class), MRB_SYM(new), MRB_SYM(flatten_merge), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_13[22] = {
0x34,0x00,0x00,0x00,0x12,0x02,0x2f,0x02,0x00,0x00,0x2f,0x02,0x01,0x00,0x12,0x03,0x2f,0x02,0x02,0x01,
0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_13, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_13 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_13,
  NULL,gem_mrblib_mruby_set_proc_syms_13,NULL,
  gem_mrblib_mruby_set_proc_lv_13,
  NULL,					/* debug_info */
  22,0,3,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_589, 2, (MRB_SYM(Set), MRB_SYM_Q(is_a), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_589[16] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_589, 2, (MRB_SYM(e), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_589 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_589,
  NULL,gem_mrblib_mruby_set_proc_syms_589,NULL,
  gem_mrblib_mruby_set_proc_lv_589,
  NULL,					/* debug_info */
  16,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_14[1] = {
  &gem_mrblib_mruby_set_proc_irep_589,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_14, 3, (MRB_SYM(detect), MRB_SYM(flatten), MRB_SYM(replace), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_14[30] = {
0x34,0x00,0x00,0x00,0x57,0x03,0x00,0x2e,0x02,0x00,0x00,0x27,0x02,0x00,0x0b,0x2d,0x03,0x01,0x00,0x2d,
0x02,0x02,0x01,0x25,0x00,0x02,0x11,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_14, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_14 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_14,
  NULL,gem_mrblib_mruby_set_proc_syms_14,gem_mrblib_mruby_set_proc_reps_14,
  gem_mrblib_mruby_set_proc_lv_14,
  NULL,					/* debug_info */
  30,0,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_15, 2, (MRB_IVSYM(hash), MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_15[16] = {
0x34,0x04,0x00,0x00,0x19,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_15, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_15 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_15,
  NULL,gem_mrblib_mruby_set_proc_syms_15,NULL,
  gem_mrblib_mruby_set_proc_lv_15,
  NULL,					/* debug_info */
  16,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_680, 1, (MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_680[13] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_680, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_680 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_680,
  NULL,gem_mrblib_mruby_set_proc_syms_680,NULL,
  gem_mrblib_mruby_set_proc_lv_680,
  NULL,					/* debug_info */
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_16[1] = {
  &gem_mrblib_mruby_set_proc_irep_680,
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_16[1] = {
{IREP_TT_STR|(19<<2), {"\x76\x61\x6c\x75\x65\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x61\x20\x73\x65\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_16, 6, (MRB_SYM(Set), MRB_SYM_Q(is_a), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_16[61] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x0a,0x1d,0x04,
0x02,0x51,0x05,0x00,0x2d,0x03,0x03,0x02,0x2d,0x03,0x04,0x00,0x01,0x04,0x01,0x2f,0x04,0x04,0x00,0x43,
0x03,0x27,0x03,0x00,0x04,0x14,0x03,0x38,0x03,0x01,0x03,0x01,0x57,0x04,0x00,0x30,0x03,0x05,0x00,0x38,
0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_16, 2, (MRB_SYM(set), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_16 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_16,
  gem_mrblib_mruby_set_proc_pool_16,gem_mrblib_mruby_set_proc_syms_16,gem_mrblib_mruby_set_proc_reps_16,
  gem_mrblib_mruby_set_proc_lv_16,
  NULL,					/* debug_info */
  61,1,6,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_726, 1, (MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_726[13] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_726, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_726 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_726,
  NULL,gem_mrblib_mruby_set_proc_syms_726,NULL,
  gem_mrblib_mruby_set_proc_lv_726,
  NULL,					/* debug_info */
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_17[1] = {
  &gem_mrblib_mruby_set_proc_irep_726,
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_17[1] = {
{IREP_TT_STR|(19<<2), {"\x76\x61\x6c\x75\x65\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x61\x20\x73\x65\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_17, 6, (MRB_SYM(Set), MRB_SYM_Q(is_a), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_17[61] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x0a,0x1d,0x04,
0x02,0x51,0x05,0x00,0x2d,0x03,0x03,0x02,0x2d,0x03,0x04,0x00,0x01,0x04,0x01,0x2f,0x04,0x04,0x00,0x44,
0x03,0x27,0x03,0x00,0x04,0x14,0x03,0x38,0x03,0x01,0x03,0x01,0x57,0x04,0x00,0x30,0x03,0x05,0x00,0x38,
0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_17, 2, (MRB_SYM(set), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_17 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_17,
  gem_mrblib_mruby_set_proc_pool_17,gem_mrblib_mruby_set_proc_syms_17,gem_mrblib_mruby_set_proc_reps_17,
  gem_mrblib_mruby_set_proc_lv_17,
  NULL,					/* debug_info */
  61,1,6,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_772, 1, (MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_772[17] = {
0x34,0x04,0x00,0x00,0x21,0x03,0x01,0x00,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_772, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_772 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_772,
  NULL,gem_mrblib_mruby_set_proc_syms_772,NULL,
  gem_mrblib_mruby_set_proc_lv_772,
  NULL,					/* debug_info */
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_18[1] = {
  &gem_mrblib_mruby_set_proc_irep_772,
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_18[1] = {
{IREP_TT_STR|(19<<2), {"\x76\x61\x6c\x75\x65\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x61\x20\x73\x65\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_18, 6, (MRB_SYM(Set), MRB_SYM_Q(is_a), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_18[58] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x0a,0x1d,0x04,
0x02,0x51,0x05,0x00,0x2d,0x03,0x03,0x02,0x01,0x03,0x01,0x2f,0x03,0x04,0x00,0x2d,0x04,0x04,0x00,0x43,
0x03,0x27,0x03,0x00,0x04,0x14,0x03,0x38,0x03,0x57,0x04,0x00,0x2e,0x03,0x05,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_18, 2, (MRB_SYM(set), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_18 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_18,
  gem_mrblib_mruby_set_proc_pool_18,gem_mrblib_mruby_set_proc_syms_18,gem_mrblib_mruby_set_proc_reps_18,
  gem_mrblib_mruby_set_proc_lv_18,
  NULL,					/* debug_info */
  58,1,6,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_818, 1, (MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_818[17] = {
0x34,0x04,0x00,0x00,0x21,0x03,0x01,0x00,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_818, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_818 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_818,
  NULL,gem_mrblib_mruby_set_proc_syms_818,NULL,
  gem_mrblib_mruby_set_proc_lv_818,
  NULL,					/* debug_info */
  17,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_19[1] = {
  &gem_mrblib_mruby_set_proc_irep_818,
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_19[1] = {
{IREP_TT_STR|(19<<2), {"\x76\x61\x6c\x75\x65\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x61\x20\x73\x65\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_19, 6, (MRB_SYM(Set), MRB_SYM_Q(is_a), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_19[58] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x0a,0x1d,0x04,
0x02,0x51,0x05,0x00,0x2d,0x03,0x03,0x02,0x01,0x03,0x01,0x2f,0x03,0x04,0x00,0x2d,0x04,0x04,0x00,0x44,
0x03,0x27,0x03,0x00,0x04,0x14,0x03,0x38,0x03,0x57,0x04,0x00,0x2e,0x03,0x05,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_19, 2, (MRB_SYM(set), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_19 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_19,
  gem_mrblib_mruby_set_proc_pool_19,gem_mrblib_mruby_set_proc_syms_19,gem_mrblib_mruby_set_proc_reps_19,
  gem_mrblib_mruby_set_proc_lv_19,
  NULL,					/* debug_info */
  58,1,6,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_864, 1, (MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_864[17] = {
0x34,0x04,0x00,0x00,0x21,0x03,0x01,0x00,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_864, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_864 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_864,
  NULL,gem_mrblib_mruby_set_proc_syms_864,NULL,
  gem_mrblib_mruby_set_proc_lv_864,
  NULL,					/* debug_info */
  17,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_865, 1, (MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_865[13] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_865, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_865 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_865,
  NULL,gem_mrblib_mruby_set_proc_syms_865,NULL,
  gem_mrblib_mruby_set_proc_lv_865,
  NULL,					/* debug_info */
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_20[2] = {
  &gem_mrblib_mruby_set_proc_irep_864,
  &gem_mrblib_mruby_set_proc_irep_865,
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_20[1] = {
{IREP_TT_STR|(19<<2), {"\x76\x61\x6c\x75\x65\x20\x6d\x75\x73\x74\x20\x62\x65\x20\x61\x20\x73\x65\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_20, 6, (MRB_SYM(Set), MRB_SYM_Q(is_a), MRB_SYM(ArgumentError), MRB_SYM(raise), MRB_SYM(size), MRB_SYM_Q(any), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_20[67] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x0a,0x1d,0x04,
0x02,0x51,0x05,0x00,0x2d,0x03,0x03,0x02,0x2d,0x03,0x04,0x00,0x01,0x04,0x01,0x2f,0x04,0x04,0x00,0x43,
0x03,0x27,0x03,0x00,0x0a,0x57,0x04,0x00,0x2e,0x03,0x05,0x00,0x25,0x00,0x0a,0x01,0x03,0x01,0x57,0x04,
0x01,0x30,0x03,0x05,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_20, 2, (MRB_SYM(set), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_20 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_20,
  gem_mrblib_mruby_set_proc_pool_20,gem_mrblib_mruby_set_proc_syms_20,gem_mrblib_mruby_set_proc_reps_20,
  gem_mrblib_mruby_set_proc_lv_20,
  NULL,					/* debug_info */
  67,1,6,2,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_21, 2, (MRB_SYM_Q(intersect), MRB_OPSYM(not), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_21[17] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x2f,0x03,0x01,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_21, 2, (MRB_SYM(set), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_21 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_21,
  NULL,gem_mrblib_mruby_set_proc_syms_21,NULL,
  gem_mrblib_mruby_set_proc_lv_21,
  NULL,					/* debug_info */
  17,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_22, 5, (MRB_SYM_Q(block_given), MRB_SYM(each), MRB_SYM(to_enum), MRB_IVSYM(hash), MRB_SYM(each_key), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_22[35] = {
0x34,0x00,0x00,0x01,0x2d,0x02,0x00,0x00,0x26,0x02,0x00,0x09,0x10,0x03,0x01,0x2d,0x02,0x02,0x01,0x38,
0x02,0x19,0x02,0x03,0x01,0x03,0x01,0x30,0x02,0x04,0x00,0x12,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_22, 1, (MRB_SYM(block), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_22 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_22,
  NULL,gem_mrblib_mruby_set_proc_syms_22,NULL,
  gem_mrblib_mruby_set_proc_lv_22,
  NULL,					/* debug_info */
  35,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_23, 1, (MRB_IVSYM(hash), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_23[18] = {
0x34,0x04,0x00,0x00,0x19,0x03,0x00,0x01,0x04,0x01,0x13,0x05,0x24,0x03,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_23, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_23 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_23,
  NULL,gem_mrblib_mruby_set_proc_syms_23,NULL,
  gem_mrblib_mruby_set_proc_lv_23,
  NULL,					/* debug_info */
  18,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_24, 2, (MRB_SYM_Q(include), MRB_SYM(add), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_24[29] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x27,0x03,0x00,0x05,0x11,0x03,0x25,0x00,0x07,
0x01,0x04,0x01,0x2d,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_24, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_24 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_24,
  NULL,gem_mrblib_mruby_set_proc_syms_24,NULL,
  gem_mrblib_mruby_set_proc_lv_24,
  NULL,					/* debug_info */
  29,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_25, 2, (MRB_IVSYM(hash), MRB_SYM(delete), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_25[18] = {
0x34,0x04,0x00,0x00,0x19,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_25, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_25 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_25,
  NULL,gem_mrblib_mruby_set_proc_syms_25,NULL,
  gem_mrblib_mruby_set_proc_lv_25,
  NULL,					/* debug_info */
  18,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_26, 2, (MRB_SYM_Q(include), MRB_SYM(delete), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_26[29] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x27,0x03,0x00,0x0a,0x01,0x04,0x01,0x2d,0x03,
0x01,0x01,0x25,0x00,0x02,0x11,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_26, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_26 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_26,
  NULL,gem_mrblib_mruby_set_proc_syms_26,NULL,
  gem_mrblib_mruby_set_proc_lv_26,
  NULL,					/* debug_info */
  29,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1183, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1183[17] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x3b,0x03,0x00,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1183, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1183 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1183,
  NULL,gem_mrblib_mruby_set_proc_syms_1183,NULL,
  gem_mrblib_mruby_set_proc_lv_1183,
  NULL,					/* debug_info */
  17,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1184, 2, (MRB_IVSYM(hash), MRB_SYM(delete), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1184[16] = {
0x34,0x04,0x00,0x00,0x19,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1184, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1184 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1184,
  NULL,gem_mrblib_mruby_set_proc_syms_1184,NULL,
  gem_mrblib_mruby_set_proc_lv_1184,
  NULL,					/* debug_info */
  16,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_27[2] = {
  &gem_mrblib_mruby_set_proc_irep_1183,
  &gem_mrblib_mruby_set_proc_irep_1184,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_27, 5, (MRB_SYM_Q(block_given), MRB_SYM(delete_if), MRB_SYM(to_enum), MRB_SYM(select), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_27[39] = {
0x34,0x00,0x00,0x00,0x2d,0x02,0x00,0x00,0x26,0x02,0x00,0x09,0x10,0x03,0x01,0x2d,0x02,0x02,0x01,0x38,
0x02,0x57,0x03,0x00,0x2e,0x02,0x03,0x00,0x57,0x03,0x01,0x30,0x02,0x04,0x00,0x12,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_27, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_27 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_27,
  NULL,gem_mrblib_mruby_set_proc_syms_27,gem_mrblib_mruby_set_proc_reps_27,
  gem_mrblib_mruby_set_proc_lv_27,
  NULL,					/* debug_info */
  39,0,5,2,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1232, 1, (MRB_SYM(call), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1232[17] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x3b,0x03,0x00,0x01,0x2f,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1232, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1232 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1232,
  NULL,gem_mrblib_mruby_set_proc_syms_1232,NULL,
  gem_mrblib_mruby_set_proc_lv_1232,
  NULL,					/* debug_info */
  17,0,1,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1233, 2, (MRB_IVSYM(hash), MRB_SYM(delete), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1233[16] = {
0x34,0x04,0x00,0x00,0x19,0x03,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1233, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1233 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1233,
  NULL,gem_mrblib_mruby_set_proc_syms_1233,NULL,
  gem_mrblib_mruby_set_proc_lv_1233,
  NULL,					/* debug_info */
  16,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_28[2] = {
  &gem_mrblib_mruby_set_proc_irep_1232,
  &gem_mrblib_mruby_set_proc_irep_1233,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_28, 5, (MRB_SYM_Q(block_given), MRB_SYM(keep_if), MRB_SYM(to_enum), MRB_SYM(reject), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_28[39] = {
0x34,0x00,0x00,0x00,0x2d,0x02,0x00,0x00,0x26,0x02,0x00,0x09,0x10,0x03,0x01,0x2d,0x02,0x02,0x01,0x38,
0x02,0x57,0x03,0x00,0x2e,0x02,0x03,0x00,0x57,0x03,0x01,0x30,0x02,0x04,0x00,0x12,0x02,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_28, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_28 = {
  2,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_28,
  NULL,gem_mrblib_mruby_set_proc_syms_28,gem_mrblib_mruby_set_proc_reps_28,
  gem_mrblib_mruby_set_proc_lv_28,
  NULL,					/* debug_info */
  39,0,5,2,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1281, 2, (MRB_SYM(call), MRB_OPSYM(lshift), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1281[25] = {
0x34,0x04,0x00,0x00,0x21,0x03,0x02,0x00,0x01,0x05,0x01,0x3b,0x04,0x00,0x01,0x2f,0x04,0x00,0x01,0x2f,
0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1281, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1281 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1281,
  NULL,gem_mrblib_mruby_set_proc_syms_1281,NULL,
  gem_mrblib_mruby_set_proc_lv_1281,
  NULL,					/* debug_info */
  25,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_29[1] = {
  &gem_mrblib_mruby_set_proc_irep_1281,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_29, 7, (MRB_SYM_Q(block_given), MRB_SYM_B(collect), MRB_SYM(to_enum), MRB_SYM(class), MRB_SYM(new), MRB_SYM(each), MRB_SYM(replace), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_29[50] = {
0x34,0x00,0x00,0x00,0x2d,0x03,0x00,0x00,0x26,0x03,0x00,0x09,0x10,0x04,0x01,0x2d,0x03,0x02,0x01,0x38,
0x03,0x12,0x03,0x2f,0x03,0x03,0x00,0x2f,0x03,0x04,0x00,0x01,0x02,0x03,0x57,0x04,0x00,0x2e,0x03,0x05,
0x00,0x01,0x04,0x02,0x2d,0x03,0x06,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_29, 2, (0,MRB_SYM(set), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_29 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_29,
  NULL,gem_mrblib_mruby_set_proc_syms_29,gem_mrblib_mruby_set_proc_reps_29,
  gem_mrblib_mruby_set_proc_lv_29,
  NULL,					/* debug_info */
  50,0,7,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_30, 5, (MRB_SYM_Q(block_given), MRB_SYM_B(reject), MRB_SYM(to_enum), MRB_SYM(size), MRB_SYM(delete_if), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_30[57] = {
0x34,0x00,0x00,0x01,0x2d,0x03,0x00,0x00,0x26,0x03,0x00,0x09,0x10,0x04,0x01,0x2d,0x03,0x02,0x01,0x38,
0x03,0x2d,0x03,0x03,0x00,0x01,0x02,0x03,0x01,0x04,0x01,0x2e,0x03,0x04,0x00,0x2d,0x03,0x03,0x00,0x01,
0x04,0x02,0x42,0x03,0x27,0x03,0x00,0x05,0x11,0x03,0x25,0x00,0x02,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_30, 2, (MRB_SYM(block), MRB_SYM(n), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_30 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_30,
  NULL,gem_mrblib_mruby_set_proc_syms_30,NULL,
  gem_mrblib_mruby_set_proc_lv_30,
  NULL,					/* debug_info */
  57,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_31, 5, (MRB_SYM_Q(block_given), MRB_SYM_B(select), MRB_SYM(to_enum), MRB_SYM(size), MRB_SYM(keep_if), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_31[57] = {
0x34,0x00,0x00,0x01,0x2d,0x03,0x00,0x00,0x26,0x03,0x00,0x09,0x10,0x04,0x01,0x2d,0x03,0x02,0x01,0x38,
0x03,0x2d,0x03,0x03,0x00,0x01,0x02,0x03,0x01,0x04,0x01,0x2e,0x03,0x04,0x00,0x2d,0x03,0x03,0x00,0x01,
0x04,0x02,0x42,0x03,0x27,0x03,0x00,0x05,0x11,0x03,0x25,0x00,0x02,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_31, 2, (MRB_SYM(block), MRB_SYM(n), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_31 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_31,
  NULL,gem_mrblib_mruby_set_proc_syms_31,NULL,
  gem_mrblib_mruby_set_proc_lv_31,
  NULL,					/* debug_info */
  57,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1417, 1, (MRB_SYM(add), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1417[13] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1417, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1417 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1417,
  NULL,gem_mrblib_mruby_set_proc_syms_1417,NULL,
  gem_mrblib_mruby_set_proc_lv_1417,
  NULL,					/* debug_info */
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_32[1] = {
  &gem_mrblib_mruby_set_proc_irep_1417,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_32, 6, (MRB_SYM(class), MRB_SYM_Q(instance_of), MRB_IVSYM(hash), MRB_SYM(__get_hash), MRB_SYM_B(merge), MRB_SYM(__do_with_enum), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_32[52] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x12,0x04,0x2f,0x04,0x00,0x00,0x2f,0x03,0x01,0x01,0x27,0x03,0x00,
0x11,0x19,0x03,0x02,0x01,0x04,0x01,0x2f,0x04,0x03,0x00,0x2f,0x03,0x04,0x01,0x25,0x00,0x0a,0x01,0x04,
0x01,0x57,0x05,0x00,0x2e,0x03,0x05,0x01,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_32, 2, (MRB_SYM(enum), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_32 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_32,
  NULL,gem_mrblib_mruby_set_proc_syms_32,gem_mrblib_mruby_set_proc_reps_32,
  gem_mrblib_mruby_set_proc_lv_32,
  NULL,					/* debug_info */
  52,0,6,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1463, 1, (MRB_SYM(delete), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1463[13] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1463, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1463 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1463,
  NULL,gem_mrblib_mruby_set_proc_syms_1463,NULL,
  gem_mrblib_mruby_set_proc_lv_1463,
  NULL,					/* debug_info */
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_33[1] = {
  &gem_mrblib_mruby_set_proc_irep_1463,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_33, 1, (MRB_SYM(__do_with_enum), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_33[18] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x57,0x05,0x00,0x2e,0x03,0x00,0x01,0x12,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_33, 2, (MRB_SYM(enum), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_33 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_33,
  NULL,gem_mrblib_mruby_set_proc_syms_33,gem_mrblib_mruby_set_proc_reps_33,
  gem_mrblib_mruby_set_proc_lv_33,
  NULL,					/* debug_info */
  18,0,1,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_34, 2, (MRB_SYM(dup), MRB_SYM(merge), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_34[17] = {
0x34,0x04,0x00,0x00,0x2d,0x03,0x00,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_34, 2, (MRB_SYM(enum), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_34 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_34,
  NULL,gem_mrblib_mruby_set_proc_syms_34,NULL,
  gem_mrblib_mruby_set_proc_lv_34,
  NULL,					/* debug_info */
  17,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_35, 2, (MRB_SYM(dup), MRB_SYM(subtract), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_35[17] = {
0x34,0x04,0x00,0x00,0x2d,0x03,0x00,0x00,0x01,0x04,0x01,0x2f,0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_35, 2, (MRB_SYM(enum), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_35 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_35,
  NULL,gem_mrblib_mruby_set_proc_syms_35,NULL,
  gem_mrblib_mruby_set_proc_lv_35,
  NULL,					/* debug_info */
  17,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1599, 2, (MRB_SYM_Q(include), MRB_SYM(add), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1599[33] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x27,0x03,0x00,0x0e,0x21,0x03,0x03,0x00,0x01,
0x04,0x01,0x2f,0x03,0x01,0x01,0x25,0x00,0x02,0x11,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1599, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1599 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1599,
  NULL,gem_mrblib_mruby_set_proc_syms_1599,NULL,
  gem_mrblib_mruby_set_proc_lv_1599,
  NULL,					/* debug_info */
  33,0,2,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_36[1] = {
  &gem_mrblib_mruby_set_proc_irep_1599,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_36, 3, (MRB_SYM(Set), MRB_SYM(new), MRB_SYM(__do_with_enum), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_36[26] = {
0x34,0x04,0x00,0x00,0x1d,0x04,0x00,0x2f,0x04,0x01,0x00,0x01,0x03,0x04,0x01,0x05,0x01,0x57,0x06,0x00,
0x2e,0x04,0x02,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_36, 3, (MRB_SYM(enum), 0,MRB_SYM(n), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_36 = {
  4,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_36,
  NULL,gem_mrblib_mruby_set_proc_syms_36,gem_mrblib_mruby_set_proc_reps_36,
  gem_mrblib_mruby_set_proc_lv_36,
  NULL,					/* debug_info */
  26,0,3,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_37, 4, (MRB_SYM(Set), MRB_SYM(new), MRB_OPSYM(or), MRB_OPSYM(and), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_37[40] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x1d,0x04,0x00,0x01,0x05,0x01,0x2f,0x04,0x01,0x01,0x2f,0x03,0x02,0x01,
0x12,0x04,0x1d,0x05,0x00,0x01,0x06,0x01,0x2f,0x05,0x01,0x01,0x2f,0x04,0x03,0x01,0x3e,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_37, 2, (MRB_SYM(enum), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_37 = {
  3,8,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_37,
  NULL,gem_mrblib_mruby_set_proc_syms_37,NULL,
  gem_mrblib_mruby_set_proc_lv_37,
  NULL,					/* debug_info */
  40,0,4,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1690, 1, (MRB_SYM_Q(include), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1690[13] = {
0x34,0x04,0x00,0x00,0x01,0x04,0x01,0x2d,0x03,0x00,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1690, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1690 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1690,
  NULL,gem_mrblib_mruby_set_proc_syms_1690,NULL,
  gem_mrblib_mruby_set_proc_lv_1690,
  NULL,					/* debug_info */
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_38[1] = {
  &gem_mrblib_mruby_set_proc_irep_1690,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_38, 8, (MRB_SYM_Q(equal), MRB_SYM(class), MRB_SYM_Q(instance_of), MRB_SYM(size), MRB_IVSYM(hash), MRB_SYM(__get_hash), MRB_SYM_Q(is_a), MRB_SYM_Q(all), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_38[126] = {
0x34,0x04,0x00,0x00,0x12,0x03,0x01,0x04,0x01,0x2f,0x03,0x00,0x01,0x27,0x03,0x00,0x05,0x13,0x03,0x25,
0x00,0x66,0x01,0x03,0x01,0x12,0x04,0x2f,0x04,0x01,0x00,0x2f,0x03,0x02,0x01,0x27,0x03,0x00,0x0f,0x12,
0x03,0x2f,0x03,0x03,0x00,0x01,0x04,0x01,0x2f,0x04,0x03,0x00,0x42,0x03,0x27,0x03,0x00,0x0f,0x19,0x03,
0x04,0x01,0x04,0x01,0x2f,0x04,0x05,0x00,0x42,0x03,0x25,0x00,0x33,0x01,0x03,0x01,0x12,0x04,0x2f,0x04,
0x01,0x00,0x2f,0x03,0x06,0x01,0x27,0x03,0x00,0x0f,0x12,0x03,0x2f,0x03,0x03,0x00,0x01,0x04,0x01,0x2f,
0x04,0x03,0x00,0x42,0x03,0x27,0x03,0x00,0x0d,0x01,0x03,0x01,0x57,0x04,0x00,0x30,0x03,0x07,0x00,0x25,
0x00,0x02,0x14,0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_38, 2, (MRB_SYM(other), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_38 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_38,
  NULL,gem_mrblib_mruby_set_proc_syms_38,gem_mrblib_mruby_set_proc_reps_38,
  gem_mrblib_mruby_set_proc_lv_38,
  NULL,					/* debug_info */
  126,0,8,1,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_39, 7, (MRB_SYM(Set), MRB_SYM_Q(is_a), MRB_SYM(size), MRB_OPSYM(cmp), MRB_OPSYM(eqq), MRB_SYM_Q(proper_subset), MRB_SYM_Q(proper_superset), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_39[136] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x04,0x11,0x03,
0x38,0x03,0x2d,0x03,0x02,0x00,0x01,0x04,0x01,0x2f,0x04,0x02,0x00,0x2f,0x03,0x03,0x01,0x05,0x04,0x01,
0x05,0x03,0x2f,0x04,0x04,0x01,0x26,0x04,0x00,0x03,0x25,0x00,0x15,0x01,0x05,0x01,0x2d,0x04,0x05,0x01,
0x27,0x04,0x00,0x05,0x05,0x04,0x25,0x00,0x02,0x11,0x04,0x25,0x00,0x3c,0x07,0x04,0x01,0x05,0x03,0x2f,
0x04,0x04,0x01,0x26,0x04,0x00,0x03,0x25,0x00,0x15,0x01,0x05,0x01,0x2d,0x04,0x06,0x01,0x27,0x04,0x00,
0x05,0x07,0x04,0x25,0x00,0x02,0x11,0x04,0x25,0x00,0x17,0x12,0x04,0x01,0x05,0x01,0x42,0x04,0x27,0x04,
0x00,0x05,0x06,0x04,0x25,0x00,0x02,0x11,0x04,0x25,0x00,0x02,0x11,0x04,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_39, 2, (MRB_SYM(set), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_39 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_39,
  NULL,gem_mrblib_mruby_set_proc_syms_39,NULL,
  gem_mrblib_mruby_set_proc_lv_39,
  NULL,					/* debug_info */
  136,0,7,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_40, 2, (MRB_IVSYM(hash), MRB_SYM(hash), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_40[13] = {
0x34,0x00,0x00,0x00,0x19,0x02,0x00,0x2f,0x02,0x01,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_40, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_40 = {
  2,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_40,
  NULL,gem_mrblib_mruby_set_proc_syms_40,NULL,
  gem_mrblib_mruby_set_proc_lv_40,
  NULL,					/* debug_info */
  13,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_41, 5, (MRB_SYM(Set), MRB_SYM_Q(is_a), MRB_IVSYM(hash), MRB_SYM(__get_hash), MRB_SYM_Q(eql), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_41[38] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x1d,0x04,0x00,0x2f,0x03,0x01,0x01,0x26,0x03,0x00,0x04,0x14,0x03,
0x38,0x03,0x19,0x03,0x02,0x01,0x04,0x01,0x2f,0x04,0x03,0x00,0x2f,0x03,0x04,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_41, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_41 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_41,
  NULL,gem_mrblib_mruby_set_proc_syms_41,NULL,
  gem_mrblib_mruby_set_proc_lv_41,
  NULL,					/* debug_info */
  38,0,5,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1871, 6, (MRB_SYM(call), MRB_OPSYM(aref), MRB_SYM(class), MRB_SYM(new), MRB_OPSYM(aset), MRB_SYM(add), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1871[68] = {
0x34,0x04,0x00,0x00,0x01,0x05,0x01,0x3b,0x04,0x00,0x01,0x2f,0x04,0x00,0x01,0x01,0x03,0x04,0x21,0x05,
0x02,0x00,0x01,0x06,0x03,0x01,0x07,0x05,0x01,0x08,0x06,0x2f,0x07,0x01,0x01,0x01,0x04,0x07,0x26,0x07,
0x00,0x11,0x12,0x07,0x2f,0x07,0x02,0x00,0x2f,0x07,0x03,0x00,0x01,0x04,0x07,0x2f,0x05,0x04,0x02,0x01,
0x05,0x01,0x2f,0x04,0x05,0x01,0x38,0x04,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_1871, 3, (MRB_SYM(i), 0,MRB_SYM(x), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1871 = {
  4,10,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1871,
  NULL,gem_mrblib_mruby_set_proc_syms_1871,NULL,
  gem_mrblib_mruby_set_proc_lv_1871,
  NULL,					/* debug_info */
  68,0,6,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_42[1] = {
  &gem_mrblib_mruby_set_proc_irep_1871,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_42, 4, (MRB_SYM_Q(block_given), MRB_SYM(classify), MRB_SYM(to_enum), MRB_SYM(each), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_42[33] = {
0x34,0x00,0x00,0x00,0x2d,0x03,0x00,0x00,0x26,0x03,0x00,0x09,0x10,0x04,0x01,0x2d,0x03,0x02,0x01,0x38,
0x03,0x53,0x02,0x00,0x57,0x04,0x00,0x2e,0x03,0x03,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_42, 2, (0,MRB_SYM(h), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_42 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_42,
  NULL,gem_mrblib_mruby_set_proc_syms_42,gem_mrblib_mruby_set_proc_reps_42,
  gem_mrblib_mruby_set_proc_lv_42,
  NULL,					/* debug_info */
  33,0,4,1,0
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_43[1] = {
{IREP_TT_STR|(49<<2), {"\x53\x65\x74\x23\x64\x69\x76\x69\x64\x65\x20\x77\x69\x74\x68\x20\x32\x20\x61\x72\x69\x74\x79\x20\x62\x6c\x6f\x63\x6b\x20\x69\x73\x20\x6e\x6f\x74\x20\x69\x6d\x70\x6c\x65\x6d\x65\x6e\x74\x65\x64\x2e"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_43, 10, (MRB_SYM_Q(block_given), MRB_SYM(divide), MRB_SYM(to_enum), MRB_SYM(arity), MRB_SYM(NotImplementedError), MRB_SYM(raise), MRB_SYM(Set), MRB_SYM(classify), MRB_SYM(values), MRB_SYM(new), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_43[66] = {
0x34,0x00,0x00,0x01,0x2d,0x02,0x00,0x00,0x26,0x02,0x00,0x09,0x10,0x03,0x01,0x2d,0x02,0x02,0x01,0x38,
0x02,0x01,0x02,0x01,0x2f,0x02,0x03,0x00,0x08,0x03,0x42,0x02,0x27,0x02,0x00,0x0a,0x1d,0x03,0x04,0x51,
0x04,0x00,0x2d,0x02,0x05,0x02,0x1d,0x02,0x06,0x01,0x04,0x01,0x2e,0x03,0x07,0x00,0x2f,0x03,0x08,0x00,
0x2f,0x02,0x09,0x01,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_43, 1, (MRB_SYM(func), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_43 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_43,
  gem_mrblib_mruby_set_proc_pool_43,gem_mrblib_mruby_set_proc_syms_43,NULL,
  gem_mrblib_mruby_set_proc_lv_43,
  NULL,					/* debug_info */
  66,1,10,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_44, 2, (MRB_SYM(to_a), MRB_SYM(join), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_44[25] = {
0x34,0x00,0x20,0x00,0x25,0x00,0x03,0x25,0x00,0x02,0x11,0x01,0x2d,0x03,0x00,0x00,0x01,0x04,0x01,0x2f,
0x03,0x01,0x01,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_44, 2, (MRB_SYM(separator), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_44 = {
  3,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_44,
  NULL,gem_mrblib_mruby_set_proc_syms_44,NULL,
  gem_mrblib_mruby_set_proc_lv_44,
  NULL,					/* debug_info */
  25,0,2,0,0
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_2007, 1, (MRB_SYM(inspect), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_2007[13] = {
0x34,0x04,0x00,0x00,0x01,0x03,0x01,0x2f,0x03,0x00,0x00,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_2007, 2, (MRB_SYM(o), 0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_2007 = {
  3,5,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_2007,
  NULL,gem_mrblib_mruby_set_proc_syms_2007,NULL,
  gem_mrblib_mruby_set_proc_lv_2007,
  NULL,					/* debug_info */
  13,0,1,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_45[1] = {
  &gem_mrblib_mruby_set_proc_irep_2007,
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_45[6] = {
{IREP_TT_STR|(2<<2), {"\x23\x3c"}},
{IREP_TT_STR|(5<<2), {"\x3a\x20\x7b\x7d\x3e"}},
{IREP_TT_STR|(8<<2), {"\x3a\x20\x7b\x2e\x2e\x2e\x7d\x3e"}},
{IREP_TT_STR|(3<<2), {"\x3a\x20\x7b"}},
{IREP_TT_STR|(2<<2), {"\x2c\x20"}},
{IREP_TT_STR|(2<<2), {"\x7d\x3e"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_45, 5, (MRB_SYM_Q(empty), MRB_SYM(class), MRB_SYM_Q(__inspect_recursive), MRB_SYM(map), MRB_SYM(join), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_45[103] = {
0x34,0x00,0x00,0x00,0x2d,0x03,0x00,0x00,0x27,0x03,0x00,0x12,0x51,0x03,0x00,0x12,0x04,0x2f,0x04,0x01,
0x00,0x52,0x03,0x51,0x04,0x01,0x52,0x03,0x38,0x03,0x12,0x03,0x2f,0x03,0x02,0x00,0x27,0x03,0x00,0x12,
0x51,0x03,0x00,0x12,0x04,0x2f,0x04,0x01,0x00,0x52,0x03,0x51,0x04,0x02,0x52,0x03,0x38,0x03,0x57,0x04,
0x00,0x2e,0x03,0x03,0x00,0x01,0x02,0x03,0x51,0x03,0x00,0x12,0x04,0x2f,0x04,0x01,0x00,0x52,0x03,0x51,
0x04,0x03,0x52,0x03,0x01,0x04,0x02,0x51,0x05,0x04,0x2f,0x04,0x04,0x01,0x52,0x03,0x51,0x04,0x05,0x52,
0x03,0x38,0x03,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_45, 2, (0,MRB_SYM(ary), ), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_45 = {
  3,7,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_45,
  gem_mrblib_mruby_set_proc_pool_45,gem_mrblib_mruby_set_proc_syms_45,gem_mrblib_mruby_set_proc_reps_45,
  gem_mrblib_mruby_set_proc_lv_45,
  NULL,					/* debug_info */
  103,6,5,1,0
};
static const mrb_pool_value gem_mrblib_mruby_set_proc_pool_46[1] = {
{IREP_TT_STR|(23<<2), {"\x63\x61\x6e\x27\x74\x20\x6d\x6f\x64\x69\x66\x79\x20\x66\x72\x6f\x7a\x65\x6e\x20\x53\x65\x74"}},
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_46, 5, (MRB_SYM_Q(frozen), MRB_SYM(FrozenError), MRB_SYM(raise), MRB_IVSYM(hash), MRB_SYM(rehash), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_46[34] = {
0x34,0x00,0x00,0x00,0x2d,0x02,0x00,0x00,0x27,0x02,0x00,0x0d,0x1d,0x03,0x01,0x51,0x04,0x00,0x2d,0x02,
0x02,0x02,0x25,0x00,0x07,0x19,0x02,0x03,0x2f,0x02,0x04,0x00,0x38,0x02,};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_lv_46, 1, (0,), const);
static const mrb_irep gem_mrblib_mruby_set_proc_irep_46 = {
  2,6,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_46,
  gem_mrblib_mruby_set_proc_pool_46,gem_mrblib_mruby_set_proc_syms_46,NULL,
  gem_mrblib_mruby_set_proc_lv_46,
  NULL,					/* debug_info */
  34,1,5,0,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_1[45] = {
  &gem_mrblib_mruby_set_proc_irep_2,
  &gem_mrblib_mruby_set_proc_irep_3,
  &gem_mrblib_mruby_set_proc_irep_4,
  &gem_mrblib_mruby_set_proc_irep_5,
  &gem_mrblib_mruby_set_proc_irep_6,
  &gem_mrblib_mruby_set_proc_irep_7,
  &gem_mrblib_mruby_set_proc_irep_8,
  &gem_mrblib_mruby_set_proc_irep_9,
  &gem_mrblib_mruby_set_proc_irep_10,
  &gem_mrblib_mruby_set_proc_irep_11,
  &gem_mrblib_mruby_set_proc_irep_12,
  &gem_mrblib_mruby_set_proc_irep_13,
  &gem_mrblib_mruby_set_proc_irep_14,
  &gem_mrblib_mruby_set_proc_irep_15,
  &gem_mrblib_mruby_set_proc_irep_16,
  &gem_mrblib_mruby_set_proc_irep_17,
  &gem_mrblib_mruby_set_proc_irep_18,
  &gem_mrblib_mruby_set_proc_irep_19,
  &gem_mrblib_mruby_set_proc_irep_20,
  &gem_mrblib_mruby_set_proc_irep_21,
  &gem_mrblib_mruby_set_proc_irep_22,
  &gem_mrblib_mruby_set_proc_irep_23,
  &gem_mrblib_mruby_set_proc_irep_24,
  &gem_mrblib_mruby_set_proc_irep_25,
  &gem_mrblib_mruby_set_proc_irep_26,
  &gem_mrblib_mruby_set_proc_irep_27,
  &gem_mrblib_mruby_set_proc_irep_28,
  &gem_mrblib_mruby_set_proc_irep_29,
  &gem_mrblib_mruby_set_proc_irep_30,
  &gem_mrblib_mruby_set_proc_irep_31,
  &gem_mrblib_mruby_set_proc_irep_32,
  &gem_mrblib_mruby_set_proc_irep_33,
  &gem_mrblib_mruby_set_proc_irep_34,
  &gem_mrblib_mruby_set_proc_irep_35,
  &gem_mrblib_mruby_set_proc_irep_36,
  &gem_mrblib_mruby_set_proc_irep_37,
  &gem_mrblib_mruby_set_proc_irep_38,
  &gem_mrblib_mruby_set_proc_irep_39,
  &gem_mrblib_mruby_set_proc_irep_40,
  &gem_mrblib_mruby_set_proc_irep_41,
  &gem_mrblib_mruby_set_proc_irep_42,
  &gem_mrblib_mruby_set_proc_irep_43,
  &gem_mrblib_mruby_set_proc_irep_44,
  &gem_mrblib_mruby_set_proc_irep_45,
  &gem_mrblib_mruby_set_proc_irep_46,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_1, 62, (MRB_SYM(Enumerable), MRB_SYM(include), MRB_SYM(__do_with_enum), MRB_SYM(__get_hash), MRB_OPSYM(aref), MRB_SYM(initialize), MRB_SYM(initialize_copy), MRB_SYM(size), MRB_SYM(length), MRB_SYM_Q(empty), MRB_SYM(clear), MRB_SYM(replace), MRB_SYM(to_a), MRB_SYM(flatten_merge), MRB_SYM(flatten), MRB_SYM_B(flatten), MRB_SYM_Q(include), MRB_SYM_Q(member), MRB_OPSYM(eqq), MRB_SYM_Q(superset), MRB_OPSYM(ge), MRB_SYM_Q(proper_superset), MRB_OPSYM(gt), MRB_SYM_Q(subset), MRB_OPSYM(le), MRB_SYM_Q(proper_subset), MRB_OPSYM(lt), MRB_SYM_Q(intersect), MRB_SYM_Q(disjoint), MRB_SYM(each), MRB_SYM(add), MRB_OPSYM(lshift), MRB_SYM_Q(add), MRB_SYM(delete), MRB_SYM_Q(delete), MRB_SYM(delete_if), MRB_SYM(keep_if), MRB_SYM_B(collect), MRB_SYM_B(map), MRB_SYM_B(reject), MRB_SYM_B(select), MRB_SYM_B(filter), MRB_SYM(merge), MRB_SYM(subtract), MRB_OPSYM(or), MRB_OPSYM(add), MRB_SYM(union), MRB_OPSYM(sub), MRB_SYM(difference), MRB_OPSYM(and), MRB_SYM(intersection), MRB_OPSYM(xor), MRB_OPSYM(eq), MRB_OPSYM(cmp), MRB_SYM(hash), MRB_SYM_Q(eql), MRB_SYM(classify), MRB_SYM(divide), MRB_SYM(join), MRB_SYM(inspect), MRB_SYM(to_s), MRB_SYM(reset), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_1[416] = {
0x1d,0x02,0x00,0x2d,0x01,0x01,0x01,0x63,0x01,0x58,0x02,0x00,0x5f,0x01,0x02,0x63,0x01,0x58,0x02,0x01,
0x5f,0x01,0x03,0x12,0x01,0x62,0x01,0x58,0x02,0x02,0x5f,0x01,0x04,0x63,0x01,0x58,0x02,0x03,0x5f,0x01,
0x05,0x63,0x01,0x58,0x02,0x04,0x5f,0x01,0x06,0x63,0x01,0x58,0x02,0x05,0x5f,0x01,0x07,0x60,0x08,0x07,
0x63,0x01,0x58,0x02,0x06,0x5f,0x01,0x09,0x63,0x01,0x58,0x02,0x07,0x5f,0x01,0x0a,0x63,0x01,0x58,0x02,
0x08,0x5f,0x01,0x0b,0x63,0x01,0x58,0x02,0x09,0x5f,0x01,0x0c,0x63,0x01,0x58,0x02,0x0a,0x5f,0x01,0x0d,
0x63,0x01,0x58,0x02,0x0b,0x5f,0x01,0x0e,0x63,0x01,0x58,0x02,0x0c,0x5f,0x01,0x0f,0x63,0x01,0x58,0x02,
0x0d,0x5f,0x01,0x10,0x60,0x11,0x10,0x60,0x12,0x10,0x63,0x01,0x58,0x02,0x0e,0x5f,0x01,0x13,0x60,0x14,
0x13,0x63,0x01,0x58,0x02,0x0f,0x5f,0x01,0x15,0x60,0x16,0x15,0x63,0x01,0x58,0x02,0x10,0x5f,0x01,0x17,
0x60,0x18,0x17,0x63,0x01,0x58,0x02,0x11,0x5f,0x01,0x19,0x60,0x1a,0x19,0x63,0x01,0x58,0x02,0x12,0x5f,
0x01,0x1b,0x63,0x01,0x58,0x02,0x13,0x5f,0x01,0x1c,0x63,0x01,0x58,0x02,0x14,0x5f,0x01,0x1d,0x63,0x01,
0x58,0x02,0x15,0x5f,0x01,0x1e,0x60,0x1f,0x1e,0x63,0x01,0x58,0x02,0x16,0x5f,0x01,0x20,0x63,0x01,0x58,
0x02,0x17,0x5f,0x01,0x21,0x63,0x01,0x58,0x02,0x18,0x5f,0x01,0x22,0x63,0x01,0x58,0x02,0x19,0x5f,0x01,
0x23,0x63,0x01,0x58,0x02,0x1a,0x5f,0x01,0x24,0x63,0x01,0x58,0x02,0x1b,0x5f,0x01,0x25,0x60,0x26,0x25,
0x63,0x01,0x58,0x02,0x1c,0x5f,0x01,0x27,0x63,0x01,0x58,0x02,0x1d,0x5f,0x01,0x28,0x60,0x29,0x28,0x63,
0x01,0x58,0x02,0x1e,0x5f,0x01,0x2a,0x63,0x01,0x58,0x02,0x1f,0x5f,0x01,0x2b,0x63,0x01,0x58,0x02,0x20,
0x5f,0x01,0x2c,0x60,0x2d,0x2c,0x60,0x2e,0x2c,0x63,0x01,0x58,0x02,0x21,0x5f,0x01,0x2f,0x60,0x30,0x2f,
0x63,0x01,0x58,0x02,0x22,0x5f,0x01,0x31,0x60,0x32,0x31,0x63,0x01,0x58,0x02,0x23,0x5f,0x01,0x33,0x63,
0x01,0x58,0x02,0x24,0x5f,0x01,0x34,0x63,0x01,0x58,0x02,0x25,0x5f,0x01,0x35,0x63,0x01,0x58,0x02,0x26,
0x5f,0x01,0x36,0x63,0x01,0x58,0x02,0x27,0x5f,0x01,0x37,0x63,0x01,0x58,0x02,0x28,0x5f,0x01,0x38,0x63,
0x01,0x58,0x02,0x29,0x5f,0x01,0x39,0x63,0x01,0x58,0x02,0x2a,0x5f,0x01,0x3a,0x63,0x01,0x58,0x02,0x2b,
0x5f,0x01,0x3b,0x60,0x3c,0x3b,0x63,0x01,0x58,0x02,0x2c,0x5f,0x01,0x3d,0x38,0x01,};
static const mrb_irep gem_mrblib_mruby_set_proc_irep_1 = {
  1,4,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_1,
  NULL,gem_mrblib_mruby_set_proc_syms_1,gem_mrblib_mruby_set_proc_reps_1,
  NULL,					/* lv */
  NULL,					/* debug_info */
  416,0,62,45,0
};
static const mrb_irep *gem_mrblib_mruby_set_proc_reps_0[1] = {
  &gem_mrblib_mruby_set_proc_irep_1,
};
mrb_DEFINE_SYMS_VAR(gem_mrblib_mruby_set_proc_syms_0, 1, (MRB_SYM(Set), ), const);
static const mrb_code gem_mrblib_mruby_set_proc_iseq_0[13] = {
0x11,0x01,0x11,0x02,0x5c,0x01,0x00,0x5e,0x01,0x00,0x38,0x01,0x69,};
static const mrb_irep gem_mrblib_mruby_set_proc_irep_0 = {
  1,3,0,
  MRB_IREP_STATIC,gem_mrblib_mruby_set_proc_iseq_0,
  NULL,gem_mrblib_mruby_set_proc_syms_0,gem_mrblib_mruby_set_proc_reps_0,
  NULL,					/* lv */
  NULL,					/* debug_info */
  13,0,1,1,0
};
static
const struct RProc gem_mrblib_mruby_set_proc[] = {{
NULL,NULL,MRB_TT_PROC,MRB_GC_RED,0,{&gem_mrblib_mruby_set_proc_irep_0},NULL,{NULL},
}};
static void
gem_mrblib_mruby_set_proc_init_syms(mrb_state *mrb)
{
}
void mrb_mruby_set_gem_init(mrb_state *mrb);
void mrb_mruby_set_gem_final(mrb_state *mrb);

void GENERATED_TMP_mrb_mruby_set_gem_init(mrb_state *mrb) {
  gem_mrblib_mruby_set_proc_init_syms(mrb);
  mrb_load_proc(mrb, gem_mrblib_mruby_set_proc);
}

void GENERATED_TMP_mrb_mruby_set_gem_final(mrb_state *mrb) {
}
